# Simples_Calculadora

Description. 
The package simples_calculadora is used to:
	- def soma
	- def subtracao
        - def multiplicacao
        - def divisao

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install simples_calculadora

```bash
pip install simples_calculadora
```

## Author
Diego_Reis

## License
[MIT](https://choosealicense.com/licenses/mit/)